package cn.com.infosec.asn1.pkcs;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.oiw.OIWObjectIdentifiers;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class RSASSAPSSparams extends ASN1Encodable {
   public static final AlgorithmIdentifier DEFAULT_HASH_ALGORITHM;
   public static final AlgorithmIdentifier DEFAULT_MASK_GEN_FUNCTION;
   public static final DERInteger DEFAULT_SALT_LENGTH;
   public static final DERInteger DEFAULT_TRAILER_FIELD;
   private AlgorithmIdentifier hashAlgorithm;
   private AlgorithmIdentifier maskGenAlgorithm;
   private DERInteger saltLength;
   private DERInteger trailerField;

   static {
      AlgorithmIdentifier var0;
      AlgorithmIdentifier var10000 = var0 = new AlgorithmIdentifier;
      var10000.<init>(OIWObjectIdentifiers.idSHA1, new DERNull());
      DEFAULT_HASH_ALGORITHM = var10000;
      DEFAULT_MASK_GEN_FUNCTION = new AlgorithmIdentifier(PKCSObjectIdentifiers.id_mgf1, var0);
      DEFAULT_SALT_LENGTH = new DERInteger(20);
      DEFAULT_TRAILER_FIELD = new DERInteger(1);
   }

   public static RSASSAPSSparams getInstance(Object obj) {
      if (obj instanceof RSASSAPSSparams) {
         return (RSASSAPSSparams)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new RSASSAPSSparams((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public RSASSAPSSparams() {
      this.hashAlgorithm = DEFAULT_HASH_ALGORITHM;
      this.maskGenAlgorithm = DEFAULT_MASK_GEN_FUNCTION;
      this.saltLength = DEFAULT_SALT_LENGTH;
      this.trailerField = DEFAULT_TRAILER_FIELD;
   }

   public RSASSAPSSparams(AlgorithmIdentifier hashAlgorithm, AlgorithmIdentifier maskGenAlgorithm, DERInteger saltLength, DERInteger trailerField) {
      this.hashAlgorithm = hashAlgorithm;
      this.maskGenAlgorithm = maskGenAlgorithm;
      this.saltLength = saltLength;
      this.trailerField = trailerField;
   }

   public RSASSAPSSparams(ASN1Sequence seq) {
      this.hashAlgorithm = DEFAULT_HASH_ALGORITHM;
      this.maskGenAlgorithm = DEFAULT_MASK_GEN_FUNCTION;
      this.saltLength = DEFAULT_SALT_LENGTH;
      this.trailerField = DEFAULT_TRAILER_FIELD;

      for(int var2 = 0; var2 != seq.size(); ++var2) {
         ASN1TaggedObject var3;
         switch ((var3 = (ASN1TaggedObject)seq.getObjectAt(var2)).getTagNo()) {
            case 0:
               this.hashAlgorithm = AlgorithmIdentifier.getInstance(var3, true);
               break;
            case 1:
               this.maskGenAlgorithm = AlgorithmIdentifier.getInstance(var3, true);
               break;
            case 2:
               this.saltLength = DERInteger.getInstance(var3, true);
               break;
            case 3:
               this.trailerField = DERInteger.getInstance(var3, true);
               break;
            default:
               throw new IllegalArgumentException("unknown tag");
         }
      }

   }

   public AlgorithmIdentifier getHashAlgorithm() {
      return this.hashAlgorithm;
   }

   public AlgorithmIdentifier getMaskGenAlgorithm() {
      return this.maskGenAlgorithm;
   }

   public DERInteger getSaltLength() {
      return this.saltLength;
   }

   public DERInteger getTrailerField() {
      return this.trailerField;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERTaggedObject var10001;
      DERTaggedObject var2;
      AlgorithmIdentifier var3;
      if (!this.hashAlgorithm.equals(DEFAULT_HASH_ALGORITHM)) {
         var10001 = var2 = new DERTaggedObject;
         var3 = this.hashAlgorithm;
         var10001.<init>(true, 0, var3);
         var1.add(var2);
      }

      if (!this.maskGenAlgorithm.equals(DEFAULT_MASK_GEN_FUNCTION)) {
         var10001 = var2 = new DERTaggedObject;
         var3 = this.maskGenAlgorithm;
         var10001.<init>(true, 1, var3);
         var1.add(var2);
      }

      if (!this.saltLength.equals(DEFAULT_SALT_LENGTH)) {
         var10001 = var2 = new DERTaggedObject;
         DERInteger var5 = this.saltLength;
         var10001.<init>(true, 2, var5);
         var1.add(var2);
      }

      if (!this.trailerField.equals(DEFAULT_TRAILER_FIELD)) {
         var10001 = var2 = new DERTaggedObject;
         DERInteger var4 = this.trailerField;
         var10001.<init>(true, 3, var4);
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
